@@ -1,39 +1,20 @@
 import json
 
-from rich.console import Console, OverflowMethod
+from rich.console import Console
 from rich.table import Table
 
 
 class Printing:
-    def __init__(self):
-        pass
-
     def pretty_print(self, text: dict):
         console = Console(highlight=False)
 
-        languages = text["Language"]
-
-        # calculate probability of each language
-        prob_language = ""
-        if languages:
-            for i in languages:
-                prob_language += (
-                    f" [red]{i.lang}[/red] {round(i.prob * 100)}% probability"
-                )
-
         to_out = ""
-        if prob_language:
-            to_out += f"[bold #D7Afff]Possible language (ISO-639-1 code):[/bold #D7Afff]{prob_language}.\n"
 
-        if text["File Signatures"]:
+        if text["File Signatures"] and text["Regexes"]:
             to_out += "\n"
             to_out += f"[bold #D7Afff]File Identified[/bold #D7Afff] with Magic Numbers {text['File Signatures']['ISO 8859-1']}."
             to_out += f"\n[bold #D7Afff]File Description:[/bold #D7Afff] {text['File Signatures']['Description']}."
             to_out += "\n"
-        if to_out:
-            console.print(to_out)
-
-        to_out = ""
 
         if text["Regexes"]:
             to_out += "\n[bold #D7Afff]Possible Identification[/bold #D7Afff]"
@@ -54,7 +35,7 @@ class Printing:
                         + i["Regex Pattern"]["URL"]
                         + matched.replace(" ", "")
                     )
-                
+
                 if i["Regex Pattern"]["Description"]:
                     if description:
                         description = (
@@ -75,11 +56,8 @@ class Printing:
                         "None",
                     )
             console.print(to_out, table)
-
-        if not text["Regexes"] and not text["Language"]:
-            console.print(
-                "[bold #D7Afff]Could not find anything of interest.[/bold #D7Afff]"
-            )
+        if to_out == "":
+            console.print("Nothing found!")
 
         """
         # This is commented out because there's too many possible hash idenfications
